package eu.jonahbauer.raytracing.render;

import org.jetbrains.annotations.NotNull;

import java.awt.image.BufferedImage;

public class BufferedImageCanvas implements Canvas {
    private final @NotNull BufferedImage image;

    public BufferedImageCanvas(int width, int height) {
        this.image = new BufferedImage(width, height, BufferedImage.TYPE_INT_RGB);
    }

    public @NotNull BufferedImage getImage() {
        return image;
    }

    @Override
    public int width() {
        return image.getWidth();
    }

    @Override
    public int height() {
        return image.getHeight();
    }

    @Override
    public @NotNull Color get(int x, int y) {
        var rgb = image.getRGB(x, y);
        return new Color((rgb >> 16) & 0xFF, (rgb >> 8) & 0xFF, rgb & 0xFF);
    }

    @Override
    public void set(int x, int y, @NotNull Color color) {
        var rgb = color.red() << 16 | color.green() << 8 | color.blue();
        image.setRGB(x, y, rgb);
    }
}
